ProjectRenamer class

Constructors

ProjectRenamer({required Directory projectDir, bool isDryRun = false, bool isVerbose = false, bool shouldRefresh = true, bool shouldCommit = false, bool shouldBackup = true, Map<String, String> customReplacements = const {}})

Properties

customReplacements Map<String, String>
final
hashCode int
The hash code for this object.
no setterinherited
isDryRun bool
final
isVerbose bool
final
projectDir Directory
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
shouldBackup bool
final
shouldCommit bool
final
shouldRefresh bool
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
rename(String oldName, String newName, {String? newPackageName, String? newAppName}) Future<void>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited